==> slayersbeasts-fabric-1.21.1-5.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/EntMediumModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.EntMediumAnimation;
import net.invictusslayer.slayersbeasts.world.entity.EntMedium;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_5597;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class EntMediumModel<T extends EntMedium> extends class_5597<T> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ent_medium_model"), "main");
	private final class_630 root;
	private final class_630 head;

	public EntMediumModel(class_630 root) {
		this.root = root;
		this.head = root.method_32086("body").method_32086("head");
	}

	public class_630 method_32008() {
		return root;
	}

	public void setupAnim(T entity, float limbSwing, float limbSwingAmount, float ageInTicks, float netHeadYaw, float headPitch) {
		root.method_32088().forEach(class_630::method_41923);
		head.field_3675 = netHeadYaw * class_3532.field_29844 / 180F;
		method_48741(EntMediumAnimation.WALK, limbSwing, limbSwingAmount, 8, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(34, 33).method_32098(-6.0F, -3.5F, -4.0F, 12.0F, 15.0F, 8.0F, new class_5605(0.0F))
				.method_32101(48, 10).method_32098(-7.0F, -7.5F, -5.0F, 14.0F, 4.0F, 10.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-9.0F, -16.5F, -6.0F, 18.0F, 9.0F, 11.0F, new class_5605(0.0F))
				.method_32101(90, 55).method_32098(6.0F, -17.5F, -5.0F, 6.0F, 4.0F, 9.0F, new class_5605(0.0F))
				.method_32101(90, 41).method_32098(-12.0F, -17.5F, -5.0F, 6.0F, 4.0F, 9.0F, new class_5605(0.0F))
				.method_32101(47, 0).method_32098(12.0F, -17.5F, -4.0F, 4.0F, 3.0F, 7.0F, new class_5605(0.0F))
				.method_32101(31, 20).method_32098(-16.0F, -17.5F, -4.0F, 4.0F, 3.0F, 7.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -21.0F, 0.0F, 0.1309F, 0.0F, 0.0F));

		class_5610 head = body.method_32117("head", class_5606.method_32108().method_32101(0, 20).method_32098(-5.0F, -10.5F, -5.0F, 10.0F, 10.0F, 11.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -16.0F, -1.0F));

		class_5610 branch = head.method_32117("branch", class_5606.method_32108().method_32101(0, 0).method_32098(2.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-1.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, 0.5236F, 0.0F, 0.3491F));

		class_5610 branch2 = head.method_32117("branch2", class_5606.method_32108().method_32101(0, 0).method_32098(2.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-1.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, -0.3873F, 0.0665F, 0.1615F));

		class_5610 branch3 = head.method_32117("branch3", class_5606.method_32108().method_32101(0, 0).method_32098(-1.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-4.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, 0.3054F, 0.0F, 0.1309F));

		class_5610 branch4 = head.method_32117("branch4", class_5606.method_32108().method_32101(0, 0).method_32098(-3.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-6.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, -0.48F, 0.0F, -0.3491F));

		class_5610 branch5 = head.method_32117("branch5", class_5606.method_32108().method_32101(0, 0).method_32098(-3.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-6.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, 0.1745F, 0.0F, -0.5672F));

		class_5610 arm_left = body.method_32117("arm_left", class_5606.method_32108().method_32101(100, 19).method_32098(2.0F, -2.5F, -3.0F, 4.0F, 11.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32090(7.0F, -14.0F, 0.0F));

		class_5610 arm_lower_left = arm_left.method_32117("arm_lower_left", class_5606.method_32108().method_32101(66, 24).method_32098(-4.0F, 10.0F, -4.5F, 8.0F, 8.0F, 9.0F, new class_5605(0.0F))
				.method_32101(80, 100).method_32098(2.0F, 18.0F, -3.5F, 2.0F, 3.0F, 7.0F, new class_5605(0.0F))
				.method_32101(87, 81).method_32098(-3.0F, -2.0F, -3.5F, 6.0F, 12.0F, 7.0F, new class_5605(0.0F)), class_5603.method_32090(4.0F, 9.5F, -0.5F));

		class_5610 arm_right = body.method_32117("arm_right", class_5606.method_32108().method_32101(24, 96).method_32098(-6.0F, -2.5F, -3.0F, 4.0F, 11.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32090(-7.0F, -14.0F, 0.0F));

		class_5610 arm_lower_right = arm_right.method_32117("arm_lower_right", class_5606.method_32108().method_32101(94, 68).method_32098(-4.0F, 18.0F, -3.5F, 2.0F, 3.0F, 7.0F, new class_5605(0.0F))
				.method_32101(86, 0).method_32098(-3.0F, -2.0F, -3.5F, 6.0F, 12.0F, 7.0F, new class_5605(0.0F))
				.method_32101(65, 47).method_32098(-4.0F, 10.0F, -4.5F, 8.0F, 8.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32090(-4.0F, 9.5F, -0.5F));

		class_5610 leg_left = body.method_32117("leg_left", class_5606.method_32108().method_32101(0, 88).method_32098(-3.0F, -1.5F, -3.0F, 6.0F, 15.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, 11.0F, 0.0F, -0.3927F, -0.3491F, 0.0F));

		class_5610 leg_lower_left = leg_left.method_32117("leg_lower_left", class_5606.method_32108().method_32101(0, 46).method_32098(-5.0F, 13.5F, -2.0F, 10.0F, 8.0F, 10.0F, new class_5605(0.0F))
				.method_32101(0, 66).method_32098(-4.0F, -0.5F, -1.0F, 8.0F, 14.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 14.0F, -3.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 leg_right = body.method_32117("leg_right", class_5606.method_32108().method_32101(56, 88).method_32098(-3.0F, -1.5F, -3.0F, 6.0F, 15.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, 11.0F, 0.0F, -0.3927F, 0.3491F, 0.0F));

		class_5610 leg_lower_right = leg_right.method_32117("leg_lower_right", class_5606.method_32108().method_32101(30, 56).method_32098(-5.0F, 13.5F, -2.0F, 10.0F, 8.0F, 10.0F, new class_5605(0.0F))
				.method_32101(62, 66).method_32098(-4.0F, -0.5F, -1.0F, 8.0F, 14.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 14.0F, -3.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 branch_left = body.method_32117("branch_left", class_5606.method_32108(), class_5603.method_32090(12.0F, -17.0F, -1.0F));

		class_5610 cube_r1 = branch_left.method_32117("cube_r1", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-3.0F, -14.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, 0.2182F, 0.0F, 0.3927F));

		class_5610 cube_r2 = branch_left.method_32117("cube_r2", class_5606.method_32108().method_32101(24, 80).method_32098(-2.0F, -11.5F, -3.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, 0.1415F, 0.1666F, -0.4681F));

		class_5610 cube_r3 = branch_left.method_32117("cube_r3", class_5606.method_32108().method_32101(24, 80).method_32098(-3.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, -0.3927F, 0.0F, 0.0F));

		class_5610 branch_right = body.method_32117("branch_right", class_5606.method_32108(), class_5603.method_32090(-12.0F, -17.0F, -1.0F));

		class_5610 cube_r4 = branch_right.method_32117("cube_r4", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-3.0F, -12.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.3054F, 0.0F, 0.0F));

		class_5610 cube_r5 = branch_right.method_32117("cube_r5", class_5606.method_32108().method_32101(24, 80).method_32098(-1.0F, -11.5F, -3.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.0F, 0.0F, -0.7854F));

		class_5610 cube_r6 = branch_right.method_32117("cube_r6", class_5606.method_32108().method_32101(24, 80).method_32098(-3.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, -0.3927F, 0.0F, 0.0F));

		return class_5607.method_32110(meshdefinition, 128, 128);
	}
}

==> slayersbeasts-fabric-1.21.4-6.2.0-sources.jar: net/invictusslayer/slayersbeasts/client/model/EntMediumModel.java <==
package net.invictusslayer.slayersbeasts.client.model;

import net.invictusslayer.slayersbeasts.SlayersBeasts;
import net.invictusslayer.slayersbeasts.client.animation.EntMediumAnimation;
import net.invictusslayer.slayersbeasts.client.state.EntRenderState;
import net.minecraft.class_2960;
import net.minecraft.class_3532;
import net.minecraft.class_5601;
import net.minecraft.class_5603;
import net.minecraft.class_5605;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_583;
import net.minecraft.class_630;
import net.minecraft.client.model.geom.builders.*;

public class EntMediumModel extends class_583<EntRenderState> {
	public static final class_5601 LAYER_LOCATION = new class_5601(class_2960.method_60655(SlayersBeasts.MOD_ID, "ent_medium_model"), "main");
	private final class_630 head;

	public EntMediumModel(class_630 root) {
		super(root);
		this.head = root.method_32086("body").method_32086("head");
	}

	public void setupAnim(EntRenderState state) {
		super.method_2819(state);
		head.field_3675 = class_3532.method_15363(state.field_53447, -32.5F, 32.5F) * class_3532.field_29844 / 180F;
		method_62102(EntMediumAnimation.WALK, state.field_53450, state.field_53451, 8, 10);
	}

	public static class_5607 createBodyLayer() {
		class_5609 meshdefinition = new class_5609();
		class_5610 partdefinition = meshdefinition.method_32111();

		class_5610 body = partdefinition.method_32117("body", class_5606.method_32108().method_32101(34, 33).method_32098(-6.0F, -3.5F, -4.0F, 12.0F, 15.0F, 8.0F, new class_5605(0.0F))
				.method_32101(48, 10).method_32098(-7.0F, -7.5F, -5.0F, 14.0F, 4.0F, 10.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(-9.0F, -16.5F, -6.0F, 18.0F, 9.0F, 11.0F, new class_5605(0.0F))
				.method_32101(90, 55).method_32098(6.0F, -17.5F, -5.0F, 6.0F, 4.0F, 9.0F, new class_5605(0.0F))
				.method_32101(90, 41).method_32098(-12.0F, -17.5F, -5.0F, 6.0F, 4.0F, 9.0F, new class_5605(0.0F))
				.method_32101(47, 0).method_32098(12.0F, -17.5F, -4.0F, 4.0F, 3.0F, 7.0F, new class_5605(0.0F))
				.method_32101(31, 20).method_32098(-16.0F, -17.5F, -4.0F, 4.0F, 3.0F, 7.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -21.0F, 0.0F, 0.1309F, 0.0F, 0.0F));

		class_5610 head = body.method_32117("head", class_5606.method_32108().method_32101(0, 20).method_32098(-5.0F, -10.5F, -5.0F, 10.0F, 10.0F, 11.0F, new class_5605(0.0F)), class_5603.method_32090(0.0F, -16.0F, -1.0F));

		class_5610 branch = head.method_32117("branch", class_5606.method_32108().method_32101(0, 0).method_32098(2.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-1.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, 0.5236F, 0.0F, 0.3491F));

		class_5610 branch2 = head.method_32117("branch2", class_5606.method_32108().method_32101(0, 0).method_32098(2.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-1.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, -0.3873F, 0.0665F, 0.1615F));

		class_5610 branch3 = head.method_32117("branch3", class_5606.method_32108().method_32101(0, 0).method_32098(-1.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-4.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, 0.3054F, 0.0F, 0.1309F));

		class_5610 branch4 = head.method_32117("branch4", class_5606.method_32108().method_32101(0, 0).method_32098(-3.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-6.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, -0.48F, 0.0F, -0.3491F));

		class_5610 branch5 = head.method_32117("branch5", class_5606.method_32108().method_32101(0, 0).method_32098(-3.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-6.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, -10.0F, 0.0F, 0.1745F, 0.0F, -0.5672F));

		class_5610 arm_left = body.method_32117("arm_left", class_5606.method_32108().method_32101(100, 19).method_32098(2.0F, -2.5F, -3.0F, 4.0F, 11.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32090(7.0F, -14.0F, 0.0F));

		class_5610 arm_lower_left = arm_left.method_32117("arm_lower_left", class_5606.method_32108().method_32101(66, 24).method_32098(-4.0F, 10.0F, -4.5F, 8.0F, 8.0F, 9.0F, new class_5605(0.0F))
				.method_32101(80, 100).method_32098(2.0F, 18.0F, -3.5F, 2.0F, 3.0F, 7.0F, new class_5605(0.0F))
				.method_32101(87, 81).method_32098(-3.0F, -2.0F, -3.5F, 6.0F, 12.0F, 7.0F, new class_5605(0.0F)), class_5603.method_32090(4.0F, 9.5F, -0.5F));

		class_5610 arm_right = body.method_32117("arm_right", class_5606.method_32108().method_32101(24, 96).method_32098(-6.0F, -2.5F, -3.0F, 4.0F, 11.0F, 5.0F, new class_5605(0.0F)), class_5603.method_32090(-7.0F, -14.0F, 0.0F));

		class_5610 arm_lower_right = arm_right.method_32117("arm_lower_right", class_5606.method_32108().method_32101(94, 68).method_32098(-4.0F, 18.0F, -3.5F, 2.0F, 3.0F, 7.0F, new class_5605(0.0F))
				.method_32101(86, 0).method_32098(-3.0F, -2.0F, -3.5F, 6.0F, 12.0F, 7.0F, new class_5605(0.0F))
				.method_32101(65, 47).method_32098(-4.0F, 10.0F, -4.5F, 8.0F, 8.0F, 9.0F, new class_5605(0.0F)), class_5603.method_32090(-4.0F, 9.5F, -0.5F));

		class_5610 leg_left = body.method_32117("leg_left", class_5606.method_32108().method_32101(0, 88).method_32098(-3.0F, -1.5F, -3.0F, 6.0F, 15.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(3.0F, 11.0F, 0.0F, -0.3927F, -0.3491F, 0.0F));

		class_5610 leg_lower_left = leg_left.method_32117("leg_lower_left", class_5606.method_32108().method_32101(0, 46).method_32098(-5.0F, 13.5F, -2.0F, 10.0F, 8.0F, 10.0F, new class_5605(0.0F))
				.method_32101(0, 66).method_32098(-4.0F, -0.5F, -1.0F, 8.0F, 14.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 14.0F, -3.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 leg_right = body.method_32117("leg_right", class_5606.method_32108().method_32101(56, 88).method_32098(-3.0F, -1.5F, -3.0F, 6.0F, 15.0F, 6.0F, new class_5605(0.0F)), class_5603.method_32091(-3.0F, 11.0F, 0.0F, -0.3927F, 0.3491F, 0.0F));

		class_5610 leg_lower_right = leg_right.method_32117("leg_lower_right", class_5606.method_32108().method_32101(30, 56).method_32098(-5.0F, 13.5F, -2.0F, 10.0F, 8.0F, 10.0F, new class_5605(0.0F))
				.method_32101(62, 66).method_32098(-4.0F, -0.5F, -1.0F, 8.0F, 14.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 14.0F, -3.0F, 0.2618F, 0.0F, 0.0F));

		class_5610 branch_left = body.method_32117("branch_left", class_5606.method_32108(), class_5603.method_32090(12.0F, -17.0F, -1.0F));

		class_5610 cube_r1 = branch_left.method_32117("cube_r1", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-3.0F, -14.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, 0.2182F, 0.0F, 0.3927F));

		class_5610 cube_r2 = branch_left.method_32117("cube_r2", class_5606.method_32108().method_32101(24, 80).method_32098(-2.0F, -11.5F, -3.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, 0.1415F, 0.1666F, -0.4681F));

		class_5610 cube_r3 = branch_left.method_32117("cube_r3", class_5606.method_32108().method_32101(24, 80).method_32098(-3.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, -0.3927F, 0.0F, 0.0F));

		class_5610 branch_right = body.method_32117("branch_right", class_5606.method_32108(), class_5603.method_32090(-12.0F, -17.0F, -1.0F));

		class_5610 cube_r4 = branch_right.method_32117("cube_r4", class_5606.method_32108().method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F))
				.method_32101(24, 80).method_32098(-3.0F, -12.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.3054F, 0.0F, 0.0F));

		class_5610 cube_r5 = branch_right.method_32117("cube_r5", class_5606.method_32108().method_32101(24, 80).method_32098(-1.0F, -11.5F, -3.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F)), class_5603.method_32091(0.0F, 0.0F, 0.0F, 0.0F, 0.0F, -0.7854F));

		class_5610 cube_r6 = branch_right.method_32117("cube_r6", class_5606.method_32108().method_32101(24, 80).method_32098(-3.0F, -13.5F, -4.0F, 8.0F, 8.0F, 8.0F, new class_5605(0.0F))
				.method_32101(0, 0).method_32098(0.0F, -8.5F, -1.0F, 2.0F, 8.0F, 2.0F, new class_5605(0.0F)), class_5603.method_32091(-1.0F, 0.0F, 0.0F, -0.3927F, 0.0F, 0.0F));

		return class_5607.method_32110(meshdefinition, 128, 128);
	}
}
